These methods return the coefficients and their covariance matrix from an estimated translog function.
# S3 method for translogEst
coef( object, … ) # S3 method for translogEst
vcov( object, … )
an object of class translogEst.
currently ignored.
The coef method returns a vector containing all (linearly independent)
coefficients of a translog function.
The vcov method returns the covariance matrix
of all (linearly independent) coefficients of a translog function.