Learn R Programming

micEcon (version 0.6-14)

residuals.translogEst: Residuals of a Translog function

Description

Extract the residuals from the estimation of a Translog function.

Usage

# S3 method for translogEst
residuals( object, … )

Arguments

object

an object of class translogEst.

currently not used.

Value

residuals.translogEst returns a vector containing the residuals of an estimated translog function.

See Also

translogEst and residuals