Learn R Programming

micEcon (version 0.6-14)

summary.translogEst: Summarizing the Estimation of a Translog Function

Description

summary.translogEst summarizes the estimation results of a Translog Function.

Usage

# S3 method for translogEst
summary( object, … )

# S3 method for summary.translogEst print( x, … )

Arguments

object

an object of class translogEst.

x

an object of class summary.translogEst.

currently ignored.

Value

summary.translogEst returns a list of class summary.translogEst that is currently the provided object, but an element coefTable has been added and the class has been changed.

See Also

translogEst.